==> 0.5.0.tar.gz: lib/widget/vgk-damage-widget/vgk-range-details.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-sub-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-common-widget/vgk-common-widget.dart';

class VgkRangeDetails extends StatelessWidget {
  final AnimationController animationController;
  final Animation animation;
  final VgkCardHorizontalFirstWithSubDetailModel data;
  final int divider;
  const VgkRangeDetails(
      {Key key,
      this.animationController,
      this.animation,
      this.data,
      this.divider})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Padding(
              padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraSmall,
              child: Container(
                decoration: BoxDecoration(
                  color: VgkProGamingTheme.boxBackground.withOpacity(0.6),
                  borderRadius: const BorderRadius.all(Radius.circular(16.0)),
                ),
                child: Column(
                  children: generateInfoDetails(data, context, divider),
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  rangeInfo(List<Head> range) {
    var result = <Widget>[];
    range.forEach((element) {
      result.add(
        VgkCommonWidget.vgkRangeInfo(
          element.key,
          VgkProGamingTheme.intToStringConvertor(element.value),
          VgkProGamingTheme.stringToIntConvertor('100'),
        ),
      );
      result.add(SizedBox(
        height: 3,
      ));
    });
    return result;
  }

  generateInfoDetails(
      VgkCardHorizontalFirstWithSubDetailModel data, context, int divider) {
    var result = <Widget>[];
    result.add(Padding(
      padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
      child: Row(
        children: <Widget>[
          Expanded(
            child: Text(
              data.key.toUpperCase(),
              textAlign: TextAlign.left,
              style: MediaQuery.of(context).size.width >= 375
                  ? VgkProGamingTheme.h2
                  : VgkProGamingTheme.h3,
            ),
          ),
        ],
      ),
    ));
    result.add(
      Padding(
        padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
        child: Row(
          children: <Widget>[
            Expanded(
              child: Padding(
                padding: EdgeInsets.only(
                  right: VgkProGamingTheme.paddingDoubleExtraLarge,
                ),
                child: Column(children: rangeInfo(data.range)),
              ),
            ),
            Center(
              child: Stack(
                children: <Widget>[
                  Container(
                    width: 100,
                    height: 120,
                    decoration: BoxDecoration(
                      color: VgkProGamingTheme.grey.withOpacity(0.1),
                      borderRadius: BorderRadius.all(
                        Radius.circular(16.0),
                      ),
                    ),
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: <Widget>[
                        Padding(
                          padding: EdgeInsets.all(8.0),
                          child: CachedNetworkImage(
                            imageUrl: data.src,
                            progressIndicatorBuilder:
                                (context, url, downloadProgress) =>
                                    CircularProgressIndicator(
                                        value: downloadProgress.progress),
                            errorWidget: (context, url, error) =>
                                Icon(Icons.error),
                          ),
                          // child: Image.network(data.src),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
    result.add(
      Padding(
        padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
        child: Container(
          height: 2,
          decoration: BoxDecoration(
            color: VgkProGamingTheme.background,
            borderRadius: BorderRadius.all(Radius.circular(4.0)),
          ),
        ),
      ),
    );
    if (divider == 1 && data.info != null && data.info.length > 0) {
      data.info.forEach((element) {
        result.add(
          VgkCommonWidget.vgkRangeInfo(element.key, element.value, 100),
        );
      });
    }
    if (divider == 2 && data.info != null && data.info.length > 0) {
      int index = (data.info.length ~/ divider).toInt();
      if (data.info.length == 1) {
        index = 1;
      }
      int currentData = 0;
      for (var i = 0; i < index; i++) {
        var firstElement = data.info[currentData];
        var secondElement;
        if (currentData + 1 < data.info.length) {
          secondElement = data.info[currentData + 1];
        }
        currentData = currentData + 2;
        result.add(
          widgetForWeaponDetails(
            firstElement.key,
            firstElement.value,
            secondElement != null ? secondElement.key : "",
            secondElement != null ? secondElement.value : "",
          ),
        );
      }
    }
    return result;
  }
}

Widget widgetForWeaponDetails(
    firstColumnTitle, firstColumnValue, secondColumnTitle, secondColumnValue) {
  return Padding(
    padding: EdgeInsets.only(
      left: VgkProGamingTheme.paddingDoubleExtraLarge,
      right: VgkProGamingTheme.paddingDoubleExtraLarge,
      top: VgkProGamingTheme.paddingDoubleExtraSmall,
      bottom: VgkProGamingTheme.paddingDoubleExtraSmall,
    ),
    child: Row(
      children: <Widget>[
        Expanded(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                    firstColumnTitle,
                    textAlign: TextAlign.center,
                    style: VgkProGamingTheme.h2,
                  ),
                  Padding(
                    padding: EdgeInsets.only(top: 6),
                    child: Text(
                      firstColumnValue,
                      textAlign: TextAlign.center,
                      style: VgkProGamingTheme.h3WithOpacity,
                    ),
                  ),
                ],
              ),
            ],
          ),
        ),
        Expanded(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                    secondColumnTitle,
                    style: VgkProGamingTheme.h2,
                  ),
                  Padding(
                    padding: EdgeInsets.only(top: 6),
                    child: Text(
                      secondColumnValue,
                      textAlign: TextAlign.center,
                      style: VgkProGamingTheme.h3WithOpacity,
                    ),
                  ),
                ],
              ),
            ],
          ),
        )
      ],
    ),
  );
}

==> 0.5.6.tar.gz: lib/widget/vgk-damage-widget/vgk-range-details.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-sub-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-common-widget/vgk-common-widget.dart';

class VgkRangeDetails extends StatelessWidget {
  final AnimationController animationController;
  final Animation animation;
  final VgkCardHorizontaWithSubDetailModel data;
  final int divider;
  const VgkRangeDetails(
      {Key key,
      this.animationController,
      this.animation,
      this.data,
      this.divider})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Padding(
              padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraSmall,
              child: Container(
                decoration: BoxDecoration(
                  color: VgkProGamingTheme.boxBackground.withOpacity(0.6),
                  borderRadius: const BorderRadius.all(Radius.circular(16.0)),
                ),
                child: Column(
                  children: generateInfoDetails(data, context, divider),
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  rangeInfo(List<VgkHeadModel> range) {
    var result = <Widget>[];
    range.forEach((element) {
      result.add(
        VgkCommonWidget.vgkRangeInfo(
          element.key,
          VgkProGamingTheme.intToStringConvertor(element.value),
          VgkProGamingTheme.stringToIntConvertor('100'),
        ),
      );
      result.add(SizedBox(
        height: 3,
      ));
    });
    return result;
  }

  generateInfoDetails(
      VgkCardHorizontaWithSubDetailModel data, context, int divider) {
    var result = <Widget>[];
    result.add(Padding(
      padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
      child: Row(
        children: <Widget>[
          Expanded(
            child: Text(
              data.key.toUpperCase(),
              textAlign: TextAlign.left,
              style: MediaQuery.of(context).size.width >= 375
                  ? VgkProGamingTheme.h2
                  : VgkProGamingTheme.h3,
            ),
          ),
        ],
      ),
    ));
    result.add(
      Padding(
        padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
        child: Row(
          children: <Widget>[
            Expanded(
              child: Padding(
                padding: EdgeInsets.only(
                  right: VgkProGamingTheme.paddingDoubleExtraLarge,
                ),
                child: Column(children: rangeInfo(data.range)),
              ),
            ),
            Center(
              child: Stack(
                children: <Widget>[
                  Container(
                    width: 100,
                    height: 120,
                    decoration: BoxDecoration(
                      color: VgkProGamingTheme.grey.withOpacity(0.1),
                      borderRadius: BorderRadius.all(
                        Radius.circular(16.0),
                      ),
                    ),
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: <Widget>[
                        Padding(
                          padding: EdgeInsets.all(8.0),
                          child: CachedNetworkImage(
                            imageUrl: data.src,
                            progressIndicatorBuilder:
                                (context, url, downloadProgress) =>
                                    CircularProgressIndicator(
                                        value: downloadProgress.progress),
                            errorWidget: (context, url, error) =>
                                Icon(Icons.error),
                          ),
                          // child: Image.network(data.src),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
    result.add(
      Padding(
        padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
        child: Container(
          height: 2,
          decoration: BoxDecoration(
            color: VgkProGamingTheme.background,
            borderRadius: BorderRadius.all(Radius.circular(4.0)),
          ),
        ),
      ),
    );
    if (divider == 1 && data.info != null && data.info.length > 0) {
      data.info.forEach((element) {
        result.add(
          VgkCommonWidget.vgkRangeInfo(element.key, element.value, 100),
        );
      });
    }
    if (divider == 2 && data.info != null && data.info.length > 0) {
      int index = (data.info.length ~/ divider).toInt();
      if (data.info.length == 1) {
        index = 1;
      }
      int currentData = 0;
      for (var i = 0; i < index; i++) {
        var firstElement = data.info[currentData];
        var secondElement;
        if (currentData + 1 < data.info.length) {
          secondElement = data.info[currentData + 1];
        }
        currentData = currentData + 2;
        result.add(
          widgetForDamageDetails(
            firstElement.key,
            firstElement.value,
            secondElement != null ? secondElement.key : "",
            secondElement != null ? secondElement.value : "",
          ),
        );
      }
    }
    return result;
  }
}

Widget widgetForDamageDetails(
    firstColumnTitle, firstColumnValue, secondColumnTitle, secondColumnValue) {
  return Padding(
    padding: EdgeInsets.only(
      left: VgkProGamingTheme.paddingDoubleExtraLarge,
      right: VgkProGamingTheme.paddingDoubleExtraLarge,
      top: VgkProGamingTheme.paddingDoubleExtraSmall,
      bottom: VgkProGamingTheme.paddingDoubleExtraSmall,
    ),
    child: Row(
      children: <Widget>[
        Expanded(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                    firstColumnTitle,
                    textAlign: TextAlign.center,
                    style: VgkProGamingTheme.h2,
                  ),
                  Padding(
                    padding: EdgeInsets.only(top: 6),
                    child: Text(
                      firstColumnValue,
                      textAlign: TextAlign.center,
                      style: VgkProGamingTheme.h3WithOpacity,
                    ),
                  ),
                ],
              ),
            ],
          ),
        ),
        Expanded(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                    secondColumnTitle,
                    style: VgkProGamingTheme.h2,
                  ),
                  Padding(
                    padding: EdgeInsets.only(top: 6),
                    child: Text(
                      secondColumnValue,
                      textAlign: TextAlign.center,
                      style: VgkProGamingTheme.h3WithOpacity,
                    ),
                  ),
                ],
              ),
            ],
          ),
        )
      ],
    ),
  );
}
